v0.1.2 - 2019-03-14
===================

- Print out hooks being created in ``snap-helpers write-hooks``.


v0.1.1 - 2019-03-12
===================

- Add ``SnapConfigOptions.get()`` to retrieve a single option with a default


v0.1.0 - 2019-03-10
===================

- Support for listing and managing Snap services
- Improvement to the ``snap-helper-testapp`` sample snap


v0.0.1 - 2019-03-09
===================

- Initial release
